pub struct AuditLogEntry<'a> {
pub timestamp: String,
pub level: &'a str,
pub event: &'a str,
pub contract: Option<Contract<'a>>,
pub target: Option<Target<'a>>,
pub results: Option<Vec<RuleResult>>,
pub executor: Executor,
pub details: Option<&'a str>,
pub summary: Option<ProcessSummary>,
}Expand description
Top-level audit log entry.
Each line in audit-YYYY-MM-DD.jsonl will be one of these.
This is the canonical structure for all audit events:
- timestamped
- leveled (INFO, AUDIT, ERROR, etc.)
- typed by
event - optionally tied to a contract, target, results, or summary
Fields
timestamp: Stringlevel: &'a strevent: &'a strcontract: Option<Contract<'a>>target: Option<Target<'a>>results: Option<Vec<RuleResult>>executor: Executordetails: Option<&'a str>summary: Option<ProcessSummary>Trait Implementations